@@ -42,7 +42,8 @@ class NetskopeIteratorClient:
         configs = {
             "base_url": "https://{}".format(params.get(Const.NSKP_TENANT_HOSTNAME)),
             "iterator_name": params.get(Const.NSKP_ITERATOR_NAME),
-            "eventtype" : params.get(Const.NSKP_EVENT_TYPE)
+            "eventtype" : params.get(Const.NSKP_EVENT_TYPE),
+            "alerttype": params.get(Const.NSKP_ALERT_TYPE)
         }
         self.token = params.get(Const.NSKP_TOKEN)
         self.user_agent = params.get(Const.NSKP_USER_AGENT)
@@ -88,9 +89,14 @@ class NetskopeIteratorClient:
         """
         base_url = self.configs.get("base_url")
         event_type = self.configs.get("eventtype")
-        tenant = self.configs.get("tenant")
+        alert_type = self.configs.get("alerttype")
         iterator_name = self.configs.get("iterator_name")
-        url = "{}/api/v2/events/dataexport/events/{}?index={}&operation={}".format(base_url,event_type,iterator_name,op)
+
+        if alert_type and event_type == Const.EVENT_TYPE_ALERT:
+            # If the query is to download the alerts specific to the alert_type
+            url = "{}/api/v2/events/dataexport/alerts/{}?index={}&operation={}".format(base_url,alert_type,iterator_name,op)
+        else:
+            url = "{}/api/v2/events/dataexport/events/{}?index={}&operation={}".format(base_url,event_type,iterator_name,op)
         return url
 
 
@@ -142,4 +148,3 @@ class NetskopeIteratorClient:
 
         if ts < 0:
             raise ValueError("Invalid iterator operation as timestamp: {}".format(op))
-
